@@ -10,6 +10,9 @@ import (
 
 	// postgres driver.
 	_ "github.com/lib/pq"
+
+	// sqlite3 driver.
+	_ "github.com/mattn/go-sqlite3"
 )
 
 // Seed type.
