@@ -2,13 +2,26 @@ package connection
 
 import (
 	"errors"
+	"fmt"
+	"os"
 	"testing"
 
 	"github.com/danvergara/dblab/pkg/command"
 	"github.com/stretchr/testify/assert"
 )
 
+func createTempSocketFile(t *testing.T) *os.File {
+	t.Helper()
+
+	socketFile, err := os.CreateTemp("", "mysqld*.sock")
+	assert.NoError(t, err)
+
+	return socketFile
+}
+
 func TestBuildConnectionFromOptsFromURL(t *testing.T) {
+	socketFile := createTempSocketFile(t)
+
 	type given struct {
 		opts command.Options
 	}
@@ -102,6 +115,17 @@ func TestBuildConnectionFromOptsFromURL(t *testing.T) {
 				uri: "user:password@tcp(your-amazonaws-uri.com:3306)/dbname",
 			},
 		},
+		{
+			name: "valid socket connection",
+			given: given{
+				opts: command.Options{
+					URL: fmt.Sprintf("mysql://user:password@unix(%s)/dbname?charset=utf8", socketFile.Name()),
+				},
+			},
+			want: want{
+				uri: fmt.Sprintf("user:password@unix(%s)/dbname?charset=utf8", socketFile.Name()),
+			},
+		},
 		{
 			name: "error misspelled mysql",
 			given: given{
@@ -163,6 +187,8 @@ func TestBuildConnectionFromOptsFromURL(t *testing.T) {
 }
 
 func TestBuildConnectionFromOptsUserData(t *testing.T) {
+	socketFile := createTempSocketFile(t)
+
 	type given struct {
 		opts command.Options
 	}
@@ -274,6 +300,53 @@ func TestBuildConnectionFromOptsUserData(t *testing.T) {
 				uri: "user:password@tcp(your-amazonaws-uri.com:3306)/db",
 			},
 		},
+		{
+			name: "success - sockets connection",
+			given: given{
+				opts: command.Options{
+					Driver: "mysql",
+					User:   "user",
+					Pass:   "password",
+					DBName: "db",
+					Socket: socketFile.Name(),
+				},
+			},
+			want: want{
+				uri: fmt.Sprintf("user:password@unix(%s)/db?charset=utf8", socketFile.Name()),
+			},
+		},
+		{
+			name: "error - invalid socket file name",
+			given: given{
+				opts: command.Options{
+					Driver: "mysql",
+					User:   "user",
+					Pass:   "password",
+					DBName: "db",
+					Socket: "/path/to/not-wrong-file",
+				},
+			},
+			want: want{
+				hasError: true,
+				err:      ErrInvalidSocketFile,
+			},
+		},
+		{
+			name: "error - socket file do not exist",
+			given: given{
+				opts: command.Options{
+					Driver: "mysql",
+					User:   "user",
+					Pass:   "password",
+					DBName: "db",
+					Socket: "/path/to/not-existing-file.sock",
+				},
+			},
+			want: want{
+				hasError: true,
+				err:      ErrSocketFileDoNotExist,
+			},
+		},
 		// sqlite3.
 		{
 			name: "success - sqlite3 db file extension",
@@ -503,6 +576,17 @@ func TestFormatMySQLURL(t *testing.T) {
 				uri: "user:password@unix(/cloudsql/project-id:region-name:instance-name)/dbname",
 			},
 		},
+		{
+			name: "valid socket connection",
+			given: given{
+				opts: command.Options{
+					URL: "mysql://user:password@unix(/path/to/socket)/dbname?charset=utf8",
+				},
+			},
+			want: want{
+				uri: "user:password@unix(/path/to/socket)/dbname?charset=utf8",
+			},
+		},
 		{
 			name: "error misspelled mysql",
 			given: given{
@@ -594,6 +678,15 @@ func TestParseDSN(t *testing.T) {
 				uri: "mysql://user:password@unix(/cloudsql/project-id:region-name:instance-name)/dbname",
 			},
 		},
+		{
+			name: "valid socket connection",
+			given: given{
+				dsn: "mysql://user:password@unix(/path/to/socket)/dbname?charset=utf8",
+			},
+			want: want{
+				uri: "mysql://user:password@unix(/path/to/socket)/dbname?charset=utf8",
+			},
+		},
 		{
 			name: "error invalid url",
 			given: given{
